utils
=====

.. automodule:: tropycal.utils


Generic Utilities
-----------------

   .. autosummary::
      :toctree: ./

      accumulated_cyclone_energy
      wind_to_category
      category_to_wind
      classify_subtropical
      get_basin
      get_storm_classification
      get_storm_type


Colors
------

   .. autosummary::
      :toctree: ./

      get_colors_sshws
      get_colors_ef
      get_colors_pph